@@ -32,7 +32,7 @@
 static const char description[] =
     I18N_NOOP( "KDE Micro-Blogging Client." );
 
-static const char version[] = "1.0 Beta4 (0.9.92)";
+static const char version[] = "1.0";
 
 int main( int argc, char **argv )
 {
@@ -44,7 +44,7 @@ int main( int argc, char **argv )
                      "mehrdad.momeny@gmail.com", "http://identi.ca/mtux" );
     about.addAuthor( ki18n( "Andrey Esin" ), ki18n( "Developer" ),
                      "gmlastik@gmail.com", "http://twitter.com/la_stik" );
-    about.addCredit( ki18n( "Roozbeh Shafiee" ), ki18n( "Graphic designer" ), "roozbeh@roozbehonline.com" );
+    about.addCredit( ki18n( "Roozbeh Shafiee" ), ki18n( "Artworks" ), "roozbeh@roozbehonline.com" );
     about.addCredit( ki18n( "Daniel Schaal" ), ki18n( "UI improvements" ), "daniel@foto-schaal.de");
     about.addCredit( ki18n( "Stephen Henderson" ), ki18n( "Search API implementation" ), "hendersonsk@gmail.com");
     about.addCredit( ki18n( "Tejas Dinkar" ), ki18n( "Developer" ),
