@@ -108,7 +108,7 @@ MainWindow::MainWindow()
     QTimer::singleShot(0, Choqok::PluginManager::self(), SLOT( loadAllPlugins() ) );
 //     Choqok::AccountManager::self()->loadAllAccounts();
     QTimer::singleShot(0, Choqok::AccountManager::self(), SLOT( loadAllAccounts() ) );
-    
+
     connect(this, SIGNAL(updateTimelines()), SLOT(slotUpdateTimelines()));
 
     QPoint pos = Choqok::BehaviorSettings::position();
@@ -241,7 +241,7 @@ void MainWindow::setupActions()
     connect( clearAvatarCache, SIGNAL( triggered() ),
              Choqok::MediaManager::self(), SLOT(clearImageCache()) );
 
-    KAction *uploadMedium = new KAction( KIcon("arrow-up"), i18n( "Upload Medium" ), this );
+    KAction *uploadMedium = new KAction( KIcon("arrow-up"), i18n( "Upload Medium..." ), this );
     actionCollection()->addAction( QLatin1String( "choqok_upload_medium" ), uploadMedium );
     connect( uploadMedium, SIGNAL( triggered(bool)), this, SLOT(slotUploadMedium()) );
 
@@ -311,7 +311,6 @@ void MainWindow::slotConfigChoqok()
 void MainWindow::settingsChanged()
 {
     kDebug();
-    ///TODO Check if there is any account and show a message if there isn't any!
     if ( Choqok::AccountManager::self()->accounts().count() < 1 ) {
         if ( KMessageBox::questionYesNo( this, i18n( "In order to use Choqok you need \
 an account at one of the supported micro-blogging services.\n\
