@@ -174,8 +174,10 @@ QMenu* TwitterApiMicroBlog::createActionsMenu(Choqok::Account* theAccount, QWidg
 QList< Choqok::Post* > TwitterApiMicroBlog::loadTimeline( Choqok::Account *account,
                                                           const QString& timelineName)
 {
-    kDebug()<<timelineName;
     QList< Choqok::Post* > list;
+    if(timelineName.compare("Favorite") == 0)
+        return list;//NOTE Won't cache favorites, and this is for compatibility with older versions!
+    kDebug()<<timelineName;
     QString fileName = Choqok::AccountManager::generatePostBackupFileName(account->alias(), timelineName);
     KConfig postsBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
     QStringList tmpList = postsBackup.groupList();
@@ -208,6 +210,7 @@ QList< Choqok::Post* > TwitterApiMicroBlog::loadTimeline( Choqok::Account *accou
             st->author.realName = grp.readEntry( "authorRealName", QString() );
             st->author.profileImageUrl = grp.readEntry( "authorProfileImageUrl", QString() );
             st->author.description = grp.readEntry( "authorDescription" , QString() );
+            st->author.isProtected = grp.readEntry("isProtected", false);
             st->isPrivate = grp.readEntry( "isPrivate" , false );
             st->author.location = grp.readEntry("authorLocation", QString());
             st->author.homePageUrl = grp.readEntry("authorUrl", QString());
@@ -227,6 +230,8 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
                                        const QString& timelineName,
                                        const QList< Choqok::UI::PostWidget* > &timeline)
 {
+    if(timelineName.compare("Favorite") == 0)
+        return;//NOTE Won't cache favorites, and this is for compatibility with older versions!
     kDebug();
     QString fileName = Choqok::AccountManager::generatePostBackupFileName(account->alias(), timelineName);
     KConfig postsBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
@@ -258,6 +263,7 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
         grp.writeEntry( "authorDescription" , post->author.description );
         grp.writeEntry( "isPrivate" , post->isPrivate );
         grp.writeEntry( "authorLocation" , post->author.location );
+        grp.writeEntry( "isProtected" , post->author.isProtected );
         grp.writeEntry( "authorUrl" , post->author.homePageUrl );
         grp.writeEntry( "isRead" , post->isRead );
         grp.writeEntry( "repeatedFrom", post->repeatedFromUsername);
@@ -753,7 +759,7 @@ void TwitterApiMicroBlog::requestTimeLine ( Choqok::Account* theAccount, QString
     if ( page ) {
         url.addQueryItem ( "page", QString::number ( page ) );
     }
-    kDebug() << "Latest " << type << " Id: " << latestStatusId;
+    kDebug() << "Latest " << type << " Id: " << latestStatusId;// << " apiReq: " << url;
 
     KIO::StoredTransferJob *job = KIO::storedGet ( url, KIO::Reload, KIO::HideProgressInfo ) ;
     if ( !job ) {
@@ -902,6 +908,8 @@ Choqok::Post* TwitterApiMicroBlog::readPostFromDomNode(Choqok::Account* theAccou
                     post->author.description = elm3.text();
                 } else if ( elm3.tagName() == "statusnet:profile_url" ) {
                     post->author.homePageUrl = elm3.text();
+                } else if ( elm3.tagName() == "protected" ) {
+                    post->author.isProtected = elm3.text().contains("true") ? true : false;
                 }
                 node3 = node3.nextSibling();
             }
@@ -1134,6 +1142,7 @@ void TwitterApiMicroBlog::setRepeatedOfInfo(Choqok::Post* post, Choqok::Post* re
         post->author = repeatedPost->author;
         post->repeatedPostId = repeatedPost->postId;
     }
+    post->creationDateTime = repeatedPost->creationDateTime;
 }
 
 QDateTime TwitterApiMicroBlog::dateFromString ( const QString &date )
@@ -1431,6 +1440,11 @@ QString TwitterApiMicroBlog::checkXmlForError(const QByteArray& buffer)
 
 ///===================================================================
 
+QJson::Parser* TwitterApiMicroBlog::jsonParser()
+{
+    return &d->parser;
+}
+
 QString TwitterApiMicroBlog::checkJsonForError(const QByteArray& buffer)
 {
     bool ok;
@@ -1638,4 +1652,20 @@ QStringList TwitterApiMicroBlog::readUsersScreenNameFromJson(Choqok::Account* th
     return list;
 }
 
+Choqok::User TwitterApiMicroBlog::readUserFromJsonMap(Choqok::Account* theAccount, const QVariantMap& map)
+{
+    Q_UNUSED(theAccount);
+    Choqok::User u;
+    u.description = map["description"].toString();
+    u.followersCount = map["followers_count"].toUInt();
+    u.homePageUrl = map["url"].toString();
+    u.isProtected = map["protected"].toBool();
+    u.location = map["location"].toString();
+    u.profileImageUrl = map["profile_image_url"].toString();
+    u.realName = map["name"].toString();
+    u.userId = map["id"].toString();
+    u.userName = map["screen_name"].toString();
+    return u;
+}
+
 #include "twitterapimicroblog.moc"
