@@ -40,6 +40,7 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include <kmenu.h>
 #include <QCloseEvent>
 #include <qmutex.h>
+#include "timelinewidget.h"
 
 static const int _15SECS = 15000;
 static const int _MINUTE = 60000;
@@ -53,7 +54,7 @@ class PostWidget::Private
 {
     public:
         Private( Account* account, const Choqok::Post& post )
-        : mCurrentPost(post), mCurrentAccount(account)//, mRead(false)
+        : mCurrentPost(post), mCurrentAccount(account), dir("ltr"), timeline(0)
         {
         }
         QGridLayout *buttonsLayout;
@@ -67,25 +68,28 @@ class PostWidget::Private
         QString mSign;
         QString mContent;
         QString mImage;
+        QString dir;
         //END UI contents;
 
         QStringList detectedUrls;
+
+        TimelineWidget *timeline;
 };
 
 
-const QString PostWidget::ownText ("<table width=\"100%\" ><tr><td><p>%2</p></td><td width=\"5\"><!-- empty --></td><td width=\"48\" rowspan=\"2\" align=\"right\">%1</td></tr><tr><td style=\"font-size:small;\" dir=\"ltr\" align=\"right\" valign=\"bottom\">%3</td></tr></table>");
+const QString PostWidget::ownText ("<table width=\"100%\" ><tr><td dir=\"%4\"><p>%2</p></td><td width=\"5\"><!-- empty --></td><td width=\"48\" rowspan=\"2\" align=\"right\">%1</td></tr><tr><td style=\"font-size:small;\" dir=\"ltr\" align=\"right\" valign=\"bottom\">%3</td></tr></table>");
 
 const QString PostWidget::otherText ( "<table height=\"100%\" width=\"100%\"><tr><td rowspan=\"2\"\
-width=\"48\">%1</td><td width=\"5\"><!-- EMPTY HAHA --></td><td><p>%2</p></td></tr><tr><td><!-- EMPTY HAHA --></td><td style=\"font-size:small;\" dir=\"ltr\" align=\"right\" width=\"100%\" valign=\"bottom\">%3</td></tr></table>");
+width=\"48\">%1</td><td width=\"5\"><!-- EMPTY HAHA --></td><td dir=\"%4\"><p>%2</p></td></tr><tr><td><!-- EMPTY HAHA --></td><td style=\"font-size:small;\" dir=\"ltr\" align=\"right\" width=\"100%\" valign=\"bottom\">%3</td></tr></table>");
 
 const QString PostWidget::baseStyle ("KTextBrowser {border: 1px solid rgb(150,150,150);\
 border-radius:5px;}  KTextBrowser {color:%1; background-color:%2}\
 KPushButton{border:0px}");
 
 const QString protocols = "((https?|ftps?)://)";
-const QString subdomains = "(([a-z0-9-_]\\.)?)";
-const QString auth = "((([a-z0-9-_]{1,})((:[\\S]{1,})?)@)?)";
-const QString domains = "(([a-z0-9-\\x0080-\\xFFFF]){1,63}\\.)+";
+const QString subdomains = "(([a-z0-9\\-_]{1,}\\.)?)";
+const QString auth = "((([a-z0-9\\-_]{1,})((:[\\S]{1,})?)@)?)";
+const QString domains = "(([a-z0-9\\-\\x0080-\\xFFFF_]){1,63}\\.)+";
 const QString port = "(:(6553[0-5]|655[0-2][0-9]|65[0-4][\\d]{2}|6[0-4][\\d]{3}|[1-5][\\d]{4}|[1-9][\\d]{0,3}))";
 const QString zone ("((a[cdefgilmnoqrstuwxz])|(b[abdefghijlmnorstvwyz])|(c[acdfghiklmnoruvxyz])|(d[ejkmoz])|(e[ceghrstu])|\
 (f[ijkmor])|(g[abdefghilmnpqrstuwy])|(h[kmnrtu])|(i[delmnoqrst])|(j[emop])|(k[eghimnprwyz])|(l[abcikrstuvy])|\
@@ -93,7 +97,7 @@ const QString zone ("((a[cdefgilmnoqrstuwxz])|(b[abdefghijlmnorstvwyz])|(c[acdfg
 (t[cdfghjkmnoprtvwz])|(u[agksyz])|(v[aceginu])|(w[fs])|(ye)|(z[amrw])\
 |(asia|com|info|net|org|biz|name|pro|aero|cat|coop|edu|jobs|mobi|museum|tel|travel|gov|int|mil|local)|(中国)|(公司)|(网络)|(صر)|(امارات)|(рф))");
 const QString ip = "(25[0-5]|[2][0-4][0-9]|[0-1]?[\\d]{1,2})(\\.(25[0-5]|[2][0-4][0-9]|[0-1]?[\\d]{1,2})){3}";
-const QString params = "(((\\/)[\\w:/\\?#\\[\\]@!\\$&\\(\\)\\*%\\+,;=\\._~\\-\\|]{1,}|%[0-9a-f]{2})?)";
+const QString params = "(((\\/)[\\w:/\\?#\\[\\]@!\\$&\\(\\)\\*%\\+,;=\\._~\\x0080-\\xFFFF\\-\\|]{1,}|%[0-9a-f]{2})?)";
 
 const QRegExp PostWidget::mUrlRegExp("((((" + protocols + "?)" + auth +
                           subdomains +
@@ -101,6 +105,7 @@ const QRegExp PostWidget::mUrlRegExp("((((" + protocols + "?)" + auth +
                           zone + "(?!(\\w))))|(" + protocols + '(' + ip + ")+))" +
                           '(' + port + "?)" + "((\\/)?)"  +
                           params + ')', Qt::CaseInsensitive);
+const QRegExp PostWidget::dirRegExp("(RT|RD)|(@([^\\s\\W]+))|(#([^\\s\\W]+))|(!([^\\s\\W]+))");
 
 QString PostWidget::readStyle;
 QString PostWidget::unreadStyle;
@@ -118,7 +123,8 @@ PostWidget::PostWidget( Account* account, const Choqok::Post& post, QWidget* par
     connect( &d->mTimer, SIGNAL( timeout() ), this, SLOT( updateUi()) );
     connect(_mainWidget, SIGNAL(clicked(QMouseEvent*)), SLOT(mousePressEvent(QMouseEvent*)));
     connect(_mainWidget, SIGNAL(anchorClicked(QUrl)), this, SLOT(checkAnchor(QUrl)));
-//     setTextInteractionFlags( Qt::TextSelectableByKeyboard | Qt::TextSelectableByMouse );
+
+    d->timeline = qobject_cast<TimelineWidget*>(parent);
 }
 
 void PostWidget::checkAnchor(const QUrl & url)
@@ -128,7 +134,6 @@ void PostWidget::checkAnchor(const QUrl & url)
 
 PostWidget::~PostWidget()
 {
-  //Attribute "Qt::WA_DeleteOnClose" is enabled at construtor! So please use close() for deleting an object, instead of deleteLater() or delete
     delete d;
 }
 
@@ -195,9 +200,7 @@ void PostWidget::initUi()
     d->mContent = prepareStatus(d->mCurrentPost.content);
     d->mSign = generateSign();
     setupAvatar();
-    if(QLatin1String(qVersion()) < "4.7"){//Due Qt 4.7 detects and sets the direction//TODO remove this part at all
-        setDirection();
-    }
+    setDirection();
     setUiStyle();
 
     d->mContent.replace("<a href","<a style=\"text-decoration:none\" href",Qt::CaseInsensitive);
@@ -208,8 +211,9 @@ void PostWidget::initUi()
 
 void PostWidget::updateUi()
 {
-    _mainWidget->setHtml(baseText->arg(d->mImage, d->mContent,
-                                      d->mSign.arg(formatDateTime( d->mCurrentPost.creationDateTime ))));
+    _mainWidget->setHtml(baseText->arg( d->mImage, d->mContent,
+                                        d->mSign.arg(formatDateTime( d->mCurrentPost.creationDateTime )),
+                                        d->dir ));
 }
 
 void PostWidget::setStyle(const QColor& color, const QColor& back, const QColor& read, const QColor& readBack, const QColor& own, const QColor& ownBack)
@@ -367,7 +371,7 @@ QString PostWidget::prepareStatus( const QString &txt )
         static const QString hrefTemplate("<a href='%1' title='%1' target='_blank'>%2</a>");
         tmplink = hrefTemplate.arg( tmplink, link );
         text.insert( pos, tmplink );
-	}
+        }
         pos += tmplink.length();
     }
 
@@ -380,16 +384,10 @@ QString PostWidget::prepareStatus( const QString &txt )
 void PostWidget::setDirection()
 {
     QString txt = d->mCurrentPost.content;
-    txt.remove(QRegExp("RT|RD"));
-    txt.remove(QRegExp("@([^\\s\\W]+)"));
-    txt.remove(QRegExp("#([^\\s\\W]+)"));
-    txt.remove(QRegExp("!([^\\s\\W]+)"));
+    txt.remove(dirRegExp);
     txt = txt.trimmed();
-//     kDebug()<<txt<<txt.isRightToLeft();
     if( txt.isRightToLeft() ) {
-        QTextOption options(_mainWidget->document()->defaultTextOption());
-        options.setTextDirection( Qt::RightToLeft );
-        _mainWidget->document()->setDefaultTextOption(options);
+        d->dir = "rtl";
     }
 }
 
@@ -585,6 +583,11 @@ void PostWidget::addAction(KAction* action)
     TextBrowser::addAction(action);
 }
 
+TimelineWidget* PostWidget::timelineWidget() const
+{
+    return d->timeline;
+}
+
 class PostWidgetUserData::Private
 {
 public:
