@@ -22,17 +22,21 @@ along with this program; if not, see http://www.gnu.org/licenses/
 */
 #include "timelinewidget.h"
 #include "account.h"
-#include <microblog.h>
+#include "microblog.h"
 #include <QVBoxLayout>
 #include <QScrollArea>
+#include <QScrollBar>
+#include <QTimer>
 #include <qlayoutitem.h>
 #include "postwidget.h"
 #include <KDebug>
-#include "choqokbehaviorsettings.h"
 #include <QLabel>
 #include <KPushButton>
 #include <QPointer>
-#include <notifymanager.h>
+#include "notifymanager.h"
+#include "choqokappearancesettings.h"
+#include "choqokbehaviorsettings.h"
+#include <QTextDocument>
 
 namespace Choqok {
 namespace UI {
@@ -42,7 +46,7 @@ class TimelineWidget::Private
 public:
     Private(Account *account, const QString &timelineName)
         :currentAccount(account), timelineName(timelineName),
-         btnMarkAllAsRead(0), unreadCount(0), info(0)
+         btnMarkAllAsRead(0), unreadCount(0), info(0), isClosable(false)
     {
         if(account->microblog()->isValidTimeline(timelineName)) {
             info = account->microblog()->timelineInfo(timelineName);
@@ -62,12 +66,16 @@ public:
     QVBoxLayout *mainLayout;
     QHBoxLayout *titleBarLayout;
     QLabel *lblDesc;
+    QScrollArea *scrollArea;
+    int order;            // 0: web, -1: natural
     Choqok::TimelineInfo *info;
+    bool isClosable;
 };
 
 TimelineWidget::TimelineWidget(Choqok::Account* account, const QString &timelineName, QWidget* parent /*= 0*/)
     : QWidget(parent), d(new Private(account, timelineName))
 {
+    setAttribute(Qt::WA_DeleteOnClose);
     setupUi();
     loadTimeline();
 }
@@ -116,7 +124,7 @@ void TimelineWidget::setupUi()
     d->lblDesc = new QLabel(this);
     TimelineInfo *info = currentAccount()->microblog()->timelineInfo(d->timelineName);
     if(info)
-        d->lblDesc->setText(info->description);
+        d->lblDesc->setText(Qt::escape(info->description));
     d->lblDesc->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
     d->lblDesc->setWordWrap(true);
     d->lblDesc->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
@@ -125,17 +133,16 @@ void TimelineWidget::setupUi()
     d->lblDesc->setFont(fnt);
 
     QVBoxLayout *gridLayout;
-    QScrollArea *scrollArea;
     QWidget *scrollAreaWidgetContents;
     QVBoxLayout *verticalLayout_2;
     QSpacerItem *verticalSpacer;
     gridLayout = new QVBoxLayout(this);
     gridLayout->setMargin(0);
     gridLayout->setObjectName("gridLayout");
-    scrollArea = new QScrollArea(this);
-    scrollArea->setObjectName("scrollArea");
-    scrollArea->setFrameShape(QFrame::NoFrame);
-    scrollArea->setWidgetResizable(true);
+    d->scrollArea = new QScrollArea(this);
+    d->scrollArea->setObjectName("scrollArea");
+    d->scrollArea->setFrameShape(QFrame::NoFrame);
+    d->scrollArea->setWidgetResizable(true);
     scrollAreaWidgetContents = new QWidget();
     scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
     scrollAreaWidgetContents->setGeometry(QRect(0, 0, 254, 300));
@@ -152,10 +159,15 @@ void TimelineWidget::setupUi()
     d->titleBarLayout->addWidget(d->lblDesc);
     verticalLayout_2->addLayout(d->mainLayout);
 
-    scrollArea->setWidget(scrollAreaWidgetContents);
+    d->scrollArea->setWidget(scrollAreaWidgetContents);
 
     gridLayout->addLayout(d->titleBarLayout);
-    gridLayout->addWidget(scrollArea);
+    gridLayout->addWidget(d->scrollArea);
+    if (AppearanceSettings::useReverseOrder()) {
+    d->order = -1;
+    QTimer::singleShot(0, this, SLOT(scrollToBottom()));
+    } else
+    d->order = 0;
 }
 
 void TimelineWidget::removeOldPosts()
@@ -192,6 +204,7 @@ void TimelineWidget::addNewPosts( QList< Choqok::Post* >& postList)
         Choqok::NotifyManager::newPostArrived( i18np( "1 new post in %2(%3)",
                                                       "%1 new posts in %2(%3)",
                                                       unread, currentAccount()->alias(), d->timelineName ) );
+
         emit updateUnreadCount(unread);
         showMarkAllAsReadButton();
     }
@@ -203,7 +216,7 @@ void TimelineWidget::showMarkAllAsReadButton()
         d->btnMarkAllAsRead = new KPushButton(this);
         d->btnMarkAllAsRead->setIcon(KIcon("mail-mark-read"));
         d->btnMarkAllAsRead->setToolTip(i18n("Mark all as read"));
-        d->btnMarkAllAsRead->setMaximumSize(16, 16);
+        d->btnMarkAllAsRead->setMaximumSize(14, 14);
         d->btnMarkAllAsRead->setIconSize(QSize(12,12));
         connect(d->btnMarkAllAsRead, SIGNAL(clicked(bool)), SLOT(markAllAsRead()));
         d->titleBarLayout->addWidget(d->btnMarkAllAsRead);
@@ -223,7 +236,7 @@ void TimelineWidget::addPostWidgetToUi(PostWidget* widget)
             this, SLOT(slotOnePostReaded()) );
     connect( widget, SIGNAL(aboutClosing(ChoqokId,PostWidget*)),
              SLOT(postWidgetClosed(ChoqokId,PostWidget*)) );
-    d->mainLayout->insertWidget(0, widget);
+    d->mainLayout->insertWidget(d->order, widget);
     d->posts.insert(widget->currentPost().postId, widget);
     d->sortedPostsList.insert(widget->currentPost().creationDateTime, widget);
     Global::SessionManager::self()->emitNewPostWidgetAdded(widget, currentAccount(), timelineName());
@@ -252,6 +265,12 @@ void TimelineWidget::markAllAsRead()
     }
 }
 
+void TimelineWidget::scrollToBottom()
+{
+    d->scrollArea->verticalScrollBar()->
+    triggerAction(QAbstractSlider::SliderToMaximum);
+}
+
 Account* TimelineWidget::currentAccount()
 {
     return d->currentAccount;
@@ -315,6 +334,16 @@ QHBoxLayout* TimelineWidget::titleBarLayout()
     return d->titleBarLayout;
 }
 
+bool TimelineWidget::isClosable() const
+{
+    return d->isClosable;
+}
+
+void TimelineWidget::setClosable(bool isClosable)
+{
+    d->isClosable = isClosable;
+}
+
 }
 }
 #include "timelinewidget.moc"
