@@ -22,10 +22,11 @@
 
 */
 
-#ifndef TWITPICCONFIG_H
-#define TWITPICCONFIG_H
+#ifndef YOURLSCONFIG_H
+#define YOURLSCONFIG_H
 
-#include <kcmodule.h>
+#include <KCModule>
+#include <QWidget>
 #include "ui_yourlsprefs.h"
 
 class YourlsConfig : public KCModule
@@ -44,4 +45,4 @@ private:
     Ui_YourlsPrefsBase ui;
 };
 
-#endif // NOWLISTENINGCONFIG_H
+#endif // YOURLSCONFIG_H
